# -*-makefile-*-
# $Id: util-linux.make 5490 2006-05-10 09:11:38Z mkl $
#
# Copyright (C) 2003-2006 by Pengutronix e.K., Hildesheim, Germany
#          
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_UTLNX) += util-linux

#
# Paths and names
#
# don't use := here
UTIL_LINUX_VERSION	= 2.13-pre7
UTIL_LINUX		= util-linux-$(UTIL_LINUX_VERSION)
UTIL_LINUX_SUFFIX	= tar.bz2
UTIL_LINUX_URL		= http://www.kernel.org/pub/linux/utils/util-linux/testing/$(UTIL_LINUX).$(UTIL_LINUX_SUFFIX)
UTLNX_SOURCE		= $(SRCDIR)/$(UTIL_LINUX).$(UTIL_LINUX_SUFFIX)
UTIL_LINUX_DIR		= $(BUILDDIR)/$(UTIL_LINUX)

-include $(call package_depfile)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

util-linux_get: $(STATEDIR)/util-linux.get

$(STATEDIR)/util-linux.get: $(util-linux_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(UTLNX_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, $(UTIL_LINUX_URL))

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

util-linux_extract: $(STATEDIR)/util-linux.extract

$(STATEDIR)/util-linux.extract: $(util-linux_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(UTIL_LINUX_DIR))
	@$(call extract, $(UTLNX_SOURCE))
	@$(call patchin, $(UTIL_LINUX))
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

util-linux_prepare: $(STATEDIR)/util-linux.prepare

UTIL_LINUX_PATH	:= PATH=$(CROSS_PATH)
UTIL_LINUX_ENV 	:= $(CROSS_ENV)

#
# autoconf
#
UTIL_LINUX_AUTOCONF := \
	$(CROSS_AUTOCONF_USR)

ifndef PTXCONF_UTLNX_SCHEDUTILS
UTIL_LINUX_AUTOCONF += --disable-schedutils
endif

$(STATEDIR)/util-linux.prepare: $(util-linux_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(UTIL_LINUX_DIR)/config.cache)
	cd $(UTIL_LINUX_DIR) && \
		$(UTIL_LINUX_PATH) $(UTIL_LINUX_ENV) \
		./configure $(UTIL_LINUX_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

util-linux_compile: $(STATEDIR)/util-linux.compile

$(STATEDIR)/util-linux.compile: $(util-linux_compile_deps_default)
	@$(call targetinfo, $@)
	cd $(UTIL_LINUX_DIR) && $(UTIL_LINUX_PATH) make
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

util-linux_install: $(STATEDIR)/util-linux.install

$(STATEDIR)/util-linux.install: $(util-linux_install_deps_default)
	@$(call targetinfo, $@)
	@$(call install, UTIL_LINUX)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

util-linux_targetinstall: $(STATEDIR)/util-linux.targetinstall

$(STATEDIR)/util-linux.targetinstall: $(util-linux_targetinstall_deps_default)
	@$(call targetinfo, $@)

	@$(call install_init,default)
	@$(call install_fixup,PACKAGE,util-linux)
	@$(call install_fixup,PRIORITY,optional)
	@$(call install_fixup,VERSION,$(UTIL_LINUX_VERSION))
	@$(call install_fixup,SECTION,base)
	@$(call install_fixup,AUTHOR,"Robert Schwebel <r.schwebel\@pengutronix.de>")
	@$(call install_fixup,DEPENDS,)
	@$(call install_fixup,DESCRIPTION,missing)

ifdef PTXCONF_UTLNX_FDISK
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/fdisk/fdisk, /usr/sbin/fdisk)
endif
ifdef PTXCONF_UTLNX_SFDISK
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/fdisk/sfdisk, /usr/sbin/sfdisk)
endif
ifdef PTXCONF_UTLNX_CFDISK
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/fdisk/cfdisk, /usr/sbin/cfdisk)
endif

ifdef PTXCONF_UTLNX_MKSWAP
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/disk-utils/mkswap, /sbin/mkswap)
endif
ifdef PTXCONF_UTLNX_SWAPON
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/mount/swapon, /sbin/swapon)
endif

ifdef PTXCONF_UTLNX_MOUNT
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/mount/mount, /bin/mount)
endif
ifdef PTXCONF_UTLNX_UMOUNT
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/mount/umount, /bin/umount)
endif

ifdef PTXCONF_UTLNX_IPCS
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/sys-utils/ipcs, /usr/bin/ipcs)
endif
ifdef PTXCONF_UTLNX_READPROFILE
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/sys-utils/readprofile, /usr/sbin/readprofile)
endif

ifdef PTXCONF_UTLNX_CHRT
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/fdisk/chrt, /usr/sbin/chrt)
endif
ifdef PTXCONF_UTLNX_IONICE
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/fdisk/ionice, /usr/sbin/ionice)
endif
ifdef PTXCONF_UTLNX_TASKSET
	@$(call install_copy, 0, 0, 0755, $(UTIL_LINUX_DIR)/fdisk/taskset, /usr/sbin/taskset)
endif
	@$(call install_finish)

	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

util-linux_clean:
	rm -rf $(STATEDIR)/util-linux.*
	rm -rf $(IMAGEDIR)/util-linux_*
	rm -rf $(UTIL_LINUX_DIR)

# vim: syntax=make
